@@ -1,3 +1,18 @@
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 """
 Includes the test scenarios to check the index time properties of an Add-on.
 """
@@ -237,8 +252,8 @@ class IndexTimeTestTemplate(object):
         record_property("time_values", key_time)
         record_property("result_time", result_fields)
 
-        assert (
-            result_fields["e_time"] == key_time
+        assert all(
+            timestamp in result_fields["e_time"] for timestamp in key_time
         ), "Actual time {} :: Time in result {}".format(
             key_time, result_fields["e_time"]
         )
